@@ -41,7 +41,7 @@ from mavenn.src.utils import mat_data_to_vec_data, \
 class Model:
     """
     Represents a MAVE-NN model, which includes a genotype-phenotype (G-P) map
-    as well as a meaurement process. For global epistasis (GE) regression,
+    as well as a measurement process. For global epistasis (GE) regression,
     set ``regression_type='GE'``; for measurement process agnostic (MPA)
     regression, set ``regression_type='MPA'``.
 
@@ -449,6 +449,7 @@ class Model:
             early_stopping_patience=20,
             batch_size=50,
             linear_initialization=True,
+            freeze_theta=False,
             callbacks=[],
             optimizer='Adam',
             optimizer_kwargs={},
@@ -492,6 +493,12 @@ class Model:
             Whether to initialize the results of a linear regression
             computation. Has no effect when ``gpmap_type='blackbox'``.
 
+        freeze_theta: (bool)
+            Whether to set the weights of the G-P map layer to be
+            non-trainable. Note that setting ``linear_initialization=True``
+            and ``freeze_theta=True`` will set theta to be initialized at the
+            linear regression solution and then become frozen during training.
+
         callbacks: (list)
             Optional list of ``tf.keras.callbacks.Callback`` objects to use
             during training.
@@ -567,6 +574,12 @@ class Model:
               f'must be bool.')
         self.linear_initialization = linear_initialization
 
+        # Check freeze_theta
+        check(isinstance(freeze_theta, bool),
+              f'type(freeze_theta)={type(freeze_theta)};'
+              f'must be bool.')
+        self.freeze_theta = freeze_theta
+
         # Check callbacks
         check(isinstance(callbacks, list),
               f'type(callbacks)={type(callbacks)}; must be list.')
@@ -588,6 +601,11 @@ class Model:
         check(isinstance(fit_kwargs, dict),
               f'type(fit_kwargs)={type(fit_kwargs)}; must be dict.')
 
+        # set the theta/weights of the G-P map to be non-trainable
+        # if requested.
+        if self.freeze_theta:
+
+            self.layer_gpmap.trainable = False
 
         # Returns the sum of negative log likelihood contributions
         # from each sequence, which is provided as y_pred
@@ -1207,23 +1225,23 @@ class Model:
         return data_df
 
     @handle_errors
-    def I_likelihood(self,
-                     x,
-                     y,
-                     ct=None,
-                     uncertainty=True):
+    def I_variational(self,
+                      x,
+                      y,
+                      ct=None,
+                      uncertainty=True):
         """
-        Estimate likelihood information.
+        Estimate variational information.
 
-        Likelihood information, ``I_like``, is the mutual information
+        Likelihood information, ``I_var``, is the mutual information
         I[ ``phi`` ; ``y``] between latent phenotypes ``phi`` and measurements
         ``y`` under the assumption that the inferred measurement process
-        p( ``y`` | ``phi`` ) is correct. ``I_like`` is an affine transformation
+        p( ``y`` | ``phi`` ) is correct. ``I_var`` is an affine transformation
         of log likelihood and thus provides a useful metric during model
-        training. When evaluated on test data, ``I_like`` also provides a lower
+        training. When evaluated on test data, ``I_var`` also provides a lower
         bound to the predictive information ``I_pred``, which does not assume
         that the inferred measurement process is correct. The difference
-        ``I_pred - I_like`` thus quantifies the mismatch between the inferred
+        ``I_pred - I_var`` thus quantifies the mismatch between the inferred
         measurement process and the true conditional distribution
         p( ``y`` | ``phi`` ).
 
@@ -1250,15 +1268,15 @@ class Model:
             ``y`` is 2D.
 
         uncertainty: (bool)
-            Whether to estimate the uncertainty of ``I_like``.
+            Whether to estimate the uncertainty of ``I_var``.
 
         Returns
         -------
-        I_like: (float)
-            Estimated likelihood information, in bits.
+        I_var: (float)
+            Estimated variational information, in bits.
 
-        dI_like: (float)
-            Standard error for ``I_like``. Is ``0`` if ``uncertainty=False``
+        dI_var: (float)
+            Standard error for ``I_var``. Is ``0`` if ``uncertainty=False``
             is used.
         """
         if self.regression_type == 'GE':
@@ -1335,14 +1353,14 @@ class Model:
         # Compute uncertainty
         dH_y_given_phi = np.std(H_y_given_phi_n, ddof=1)/np.sqrt(N)
 
-        # Compute I_like and dI_fit
-        I_like = H_y - H_y_given_phi
+        # Compute I_var and dI_fit
+        I_var = H_y - H_y_given_phi
         if uncertainty:
-            dI_like = np.sqrt(dH_y**2 + dH_y_given_phi**2)
+            dI_var = np.sqrt(dH_y**2 + dH_y_given_phi**2)
         else:
-            dI_like = 0
+            dI_var = 0
 
-        return I_like, dI_like
+        return I_var, dI_var
 
     @handle_errors
     def I_predictive(self,
@@ -1360,7 +1378,7 @@ class Model:
 
         Predictive information, ``I_pred``, is the mutual information
         I[ ``phi`` ; ``y``] between latent phenotypes ``phi`` and measurements
-        ``y``. Unlike likelihood information, ``I_pred`` does not assume that
+        ``y``. Unlike variational information, ``I_pred`` does not assume that
         the inferred measurement process p( ``y`` | ``phi`` ) is correct.
         ``I_pred`` is estimated using the k'th nearest neighbor methods from the
         NPEET package.
@@ -1414,7 +1432,7 @@ class Model:
         Returns
         -------
         I_pred: (float)
-            Estimated likelihood information, in bits.
+            Estimated variational information, in bits.
 
         dI_pred: (float)
             Standard error for ``I_pred``. Is ``0`` if ``uncertainty=False``
